# HG changeset patch
# User Dan Drogichen <chirp.cordless@xoxy.net>
# Date 1398395064 25200
#      Thu Apr 24 20:04:24 2014 -0700
# Node ID dadb654ad6b5ecb2e42ff3e21ce9f871512e92dc
# Parent  e51624d6ad4b7cb72a3554356d71f26cfe503adb
[csv] Friendlier defaults for missing cToneFreq/rToneFreq columns in csv import - Fixes #1577

Check for the existence of csv headings "rToneFreq" and "cToneFreq" in the
header line. If exactly one is present, use the value in that column
for both rTone and cTone for each channel imported.

#1577

diff -r e51624d6ad4b -r dadb654ad6b5 chirp/generic_csv.py
--- a/chirp/generic_csv.py	Sat Apr 12 10:45:09 2014 -0700
+++ b/chirp/generic_csv.py	Thu Apr 24 20:04:24 2014 -0700
@@ -119,6 +119,25 @@
         
         return mem
 
+
+    def _clean_tmode(self, headers, line, mem):
+        """ If there is exactly one of [rToneFreq, cToneFreq] columns in the
+        csv file, use it for both rtone & ctone. Makes TSQL use friendlier."""
+
+        _file_has_rTone = 0
+        _file_has_cTone = 0
+        for header in headers:
+	    if header == "rToneFreq":
+                _file_has_rTone = 1
+	    elif header == "cToneFreq":
+                _file_has_cTone = 1
+        if _file_has_rTone and not _file_has_cTone:
+            mem.ctone = mem.rtone
+        elif _file_has_cTone and not _file_has_rTone:
+            mem.rtone = mem.ctone
+
+        return mem
+
     def _parse_csv_data_line(self, headers, line):
         mem = chirp_common.Memory()
         try:
